module Gitlab
  module Vulnerabilities
    class BaseVulnerability
      attr_reader :data

      def initialize(data)
        @data = data
      end

      # Ensure mandatory properties are defined
      %i[
        title
        description
        severity
        confidence
        solution
        identifiers
      ].each do |method_name|
        define_method(method_name) do
          raise NotImplementedError
        end
      end

      protected

      # cve_id must be 'CVE-YYYY-XXXX' (prefix + year + digits)
      def cve_link(cve_id)
        "https://cve.mitre.org/cgi-bin/cvename.cgi?name=#{cve_id}"
      end

      # cve_id must be a number only (no 'CWE-' prefix)
      def cwe_link(cwe_id)
        "https://cwe.mitre.org/data/definitions/#{cwe_id}.html"
      end
    end
  end
end
